Sketch
======

.. currentmodule:: pysylph

Database
--------

.. autoclass:: pysylph.Database
   :special-members: __init__
   :inherited-members:
   :members:


DatabaseFile
------------

.. autoclass:: pysylph.DatabaseFile
   :special-members: __init__
   :inherited-members:
   :members:
